import cv2

DEFAULT_SUBSTRACTOR = 'MOG2'

class BackgroundSubstractor:
    """
    Remove backgroud from the frame
    """

    def __init__(self, substractor=DEFAULT_SUBSTRACTOR):
        """
        Method create BackgroundSubstractor object with default MOG2 function

        Args:
                substractor (string): name of choosen substractor
        """
        if(substractor == 'MOG2'):
            self.backgroudSubstractor = cv2.createBackgroundSubtractorMOG2()
        elif(substractor == 'MOG'):
            self.backgroudSubstractor = cv2.bgsegm.createBackgroundSubtractorMOG()
        elif(substractor == 'KNN'):
            self.backgroudSubstractor = cv2.createBackgroundSubtractorKNN()
        elif(substractor == 'CNT'):
            self.backgroudSubstractor = cv2.bgsegm.createBackgroundSubtractorCNT()
        elif(substractor == 'GMG'):
            self.backgroudSubstractor = cv2.bgsegm.createBackgroundSubtractorGMG()
        elif(substractor == 'SOC'):
            self.backgroudSubstractor = cv2.bgsegm.createBackgroundSubtractorGSOC()
        elif(substractor == 'SBP'):
            self.backgroudSubstractor = cv2.bgsegm.createBackgroundSubtractorLSBP()
    
    def apply(self, frame):
        """
        Remove bacground from frame

        Args:
                frame (Mat/numpy): frame from Camera/video
        
        Return frame without background
        """
        ret_frame = self.backgroudSubstractor.apply(frame)

        return ret_frame