import cv2

DEFAULT_CAMERA = 0

class Camera:
    """
    Camera control
    """

    def __init__(self, device_number=DEFAULT_CAMERA):
        """
        Method create Camera object with default device 0

        Args:
                device_number (int): device number showed after use v4l2-ctl --list-devices
        """
        self.camera = cv2.VideoCapture(device_number)

    def set_resolution(self, width, height):
        """
        Set camera width and height

        Args:
                width (int): width of frame
                height (int): height of frame
        """
        self.camera.set(cv2.CAP_PROP_FRAME_WIDTH, width)
        self.camera.set(cv2.CAP_PROP_FRAME_HEIGHT, height)
    
    def set_fps(self, fps):
        """
        Set camera FPS

        Args:
                fps (int): camera fps
        """
        self.camera.set(cv2.CAP_PROP_FPS, fps)

    def get_camera_properties(self):
        """
        Get camera properties:

        """
        print('Width: ' + str(self.camera.get(cv2.CAP_PROP_FRAME_WIDTH)))
        print('Height: ' + str(self.camera.get(cv2.CAP_PROP_FRAME_HEIGHT)))
        print('FPS: ' + str(self.camera.get(cv2.CAP_PROP_FPS)))

    def read(self):
        """
        Return frame from camera
        """
        return self.camera.read()
    
    def init_auto_balance(self):
        """
        Method get 30 frame from camera
        Frame at begin are too bright
        """
        i = 20
        while(i):
            ret, frame = self.camera.read()
            i = i -1
    
    def is_opened(self):
        """
        Method check if camera is open
        
        Return (int): true (camera is opened)/ false (camera is not opened)
        """
        return self.camera.isOpened()
    
    def release(self):
        """
        Release camera device
        """
        return self.camera.release()

    def __del__(self):
        """
        Release camera before delete object
        """
        self.camera.release()
  
    
if __name__ == "__main__":

    camera = Camera()
    camera.set_resolution(640,480)
    camera.init_auto_balance()

    while(True):    

        ret, frame = camera.read() 
        cv2.imshow('frame', frame) 

        if cv2.waitKey(1) & 0xFF == ord('q'): 
            break
  
    camera.release() 
    cv2.destroyAllWindows() 
