import cv2
from datetime import datetime

DEFAULT_VIDEO_FRAMES = 1800
DEFAULT_VIDEO_PATH = './rec/'

class Recorder:
    """
    Record camera frames as a .avi video
    """

    def __init__(self, frame_width=640, frame_height=480, video_path=DEFAULT_VIDEO_PATH):
        """
        Method create Recorder object with default frame 640x480 and video save path ./rec/

        Args:
                frame_width (int): width of saved video (frames)
                frame_height (int): heigh of saved video (frames)
                video_path (string): path where video will be save
        """
        self.video_path = video_path
        self.now = datetime.now().strftime("%d_%m_%Y-%H_%M_%S")
        self.recorder = cv2.VideoWriter(self.video_path + self.now + '.avi', cv2.VideoWriter_fourcc('M','J','P','G'), 30, (frame_width,frame_height))
        self.tab_frame = 0

    def new_filename(self):
        """
        Create new filename with current date
        """
        self.now = datetime.now().strftime("%d_%m_%Y-%H_%M_%S")
    
    def release(self):
        """
        Release VideoWriter (save video)
        """
        self.recorder.release()

    def write(self, frame, count_frame=DEFAULT_VIDEO_FRAMES):
        """
        Method which save video file. 
        When video have requested size, funtion save file and create new video object

        Args:
                frame (Mat/numpy): frame from camera which will be added to the video
                count_frame (int): how many frames would contain video
        """
        self.recorder.write(frame)
        self.tab_frame = self.tab_frame + 1
        
        if(self.tab_frame >= count_frame):
            self.tab_frame = 0
            self.recorder.release()
            self.new_filename()
            frame_height, frame_width = frame.shape[:2]
            self.recorder = cv2.VideoWriter(self.video_path + self.now + '.avi', cv2.VideoWriter_fourcc('M','J','P','G'), 30, (frame_width,frame_height))

    def __del__(self):
        """
        Save video before delete object
        """
        self.recorder.release()
